<?php
if (!defined('BASEPATH')) exit('No direct script access allowed');

abstract class ApplicationBase
{		
	// default object 
	protected $obj_ctrl;
	protected $obj_tmpl;
	protected $arr_config;
	protected $arr_routes;	
	// global variable
	protected $arr_system_default;
	// parameter navigasi
	protected $int_nav;
	protected $int_parent;
	protected $int_parent_blok;
	protected $int_parent_group;
	// business object 	
	protected $obj_system;
	protected $obj_site;
	protected $obj_nav;
	// side bar
	private $obj_event;
	private $obj_date;
	private $obj_mailbox;
	
	function __construct(){	
	}
	
	function __destruct(){
	}
	
	/** important 
	| ---------------------------------------------------------------------------------	
	| if you not understand, do not change code below !!!
	| ---------------------------------------------------------------------------------
	*/	
	protected final function LoadController(){
		// instance controller must be loaded
		$this->obj_ctrl = BaseController::Instance();
		// load configuration
		$this->arr_config = $this->obj_ctrl->LoadConfiguration('config.php');
	}
	
	protected final function LoadPatTemplate($loaded = TRUE){
		if($loaded == TRUE){
			/*
			| patTemplate must be loaded
			| Do not remove code below
			*/
			$this->obj_ctrl->LoadFile('pattemplate/patError.php', 'plugins');
			$this->obj_ctrl->LoadFile('pattemplate/patErrorManager.php', 'plugins');
			$this->obj_ctrl->LoadFile('pattemplate/patTemplate.php', 'plugins');
			$this->obj_tmpl = $this->obj_ctrl->LoadClass('patTemplate');
			// asossiate patTemplate with controller
			$this->obj_ctrl->SetTemplateObject($this->obj_tmpl);
		}else{
			// patTemplate object not define on process page
		}
	}	
	
	public final function PageDisplay($routes){
		/** 
		| final method 
		*/
		// get aktif routes variable
		$this->arr_routes = $routes;		
		// load controller object
		$this->LoadController();		
		/** 
		| override method 
		*/
		// load object on base
		$this->BaseLoad();
		// view base content
		$this->BaseView();	
		/** 
		| abstract method 
		*/
		// load object on content
		$this->PageLoad();
		// view page content
		$this->PageView();
		// parsing output
		$this->ParseDocumentOutput();
	}
	
	protected abstract function PageLoad();
	protected abstract function PageView();
	protected abstract function ParseDocumentOutput();
	/** end of important 
	| ---------------------------------------------------------------------------------
	*/
	
	protected function SetBaseTemplates(){
		$this->obj_tmpl->setBasedir(APPPATH.$this->arr_routes['app'].'/base/templates');		
        $this->obj_tmpl->readTemplatesFromFile('document-base.html');	
        $this->obj_tmpl->readTemplatesFromFile('header-base.html');	
        $this->obj_tmpl->readTemplatesFromFile('sidebar-base.html');
        $this->obj_tmpl->readTemplatesFromFile('footer-base.html');
	}		
	
	protected function BaseLoad(){
		// load patTemplate object
		$this->LoadPatTemplate();
		// set document templates 
		$this->SetBaseTemplates();
		// default application themes
		$this->obj_ctrl->SetApplicationThemes();
		// default application layout
		$this->obj_ctrl->SetBaseLayout();
		// javascript loaded
		$this->obj_ctrl->LoadJavascript('form_event');
		$this->obj_ctrl->LoadJavascript('jquery');
		$this->obj_ctrl->LoadJavascript('jstyle-function-public', 'jquery');
		$this->obj_ctrl->LoadJavascript('jquery.corner-public', 'jquery');
		// business loaded
		$this->obj_system = $this->obj_ctrl->LoadBusiness('systemdata', 'mysql', $this->arr_config['db']);
		$this->obj_site = $this->obj_ctrl->LoadBusiness('website', 'mysql', $this->arr_config['db']);
		$this->obj_nav = $this->obj_ctrl->LoadBusiness('navigation', 'mysql', $this->arr_config['db']);
		// side bar
		$this->obj_mailbox = $this->obj_ctrl->LoadBusiness('mailbox', 'mysql', $this->arr_config['db']);
		$this->obj_event = $this->obj_ctrl->LoadBusiness('agenda', 'mysql', $this->arr_config['db']);
		$this->obj_date = $this->obj_ctrl->LoadLibrary('DateTimeManipulation');
	}
	
	protected function BaseView(){
		// parsing variable global
		self::ParseGlobalVariable();
		// error login
		self::DisplayErrorLogin();
		// web title
		self::DisplayWebTitle();
		// display features
		self::DisplayTopNavigation();
		// get system settings
		self::GetSystemSettings();
		// display event side menu
		self::DisplayListEvents();
		// display announcements
		self::DisplayListAnnouncements();
		
		// display counter 19102011
		self::DisplayCounter();
	}	
	
	/* 
	| ------------------------------------------------------------------
	| private function to parse output from business class
	| ------------------------------------------------------------------
	*/
	
	private function ParseGlobalVariable(){
		// login template variable
		$this->obj_tmpl->addVar('login', 'URL_PROCESS', $this->obj_ctrl->GetUrl($this->arr_routes['app'], 'home', 'private', 'process'));
		$this->obj_tmpl->addVar('login', 'URL_LOGOUT', $this->obj_ctrl->GetUrl('private', 'home', 'private', 'logout'));
		$this->obj_tmpl->addVar('login', 'URL_SIGN', $this->obj_ctrl->GetURL($this->arr_routes['app'], 'membership', 'informasi', 'keanggotaan'));
		$this->obj_tmpl->addVar('login', 'URL_FORGET', $this->obj_ctrl->GetURL($this->arr_routes['app'], 'membership', 'registrasi', 'forget-password'));
		$this->obj_tmpl->addVar('login', 'URL_REQUEST', $this->obj_ctrl->GetURL($this->arr_routes['app'], 'membership', 'registrasi', 'kontak-form'));
	}
	
	// system setting
	private function GetSystemSettings(){
		// get settings
		$result = $this->obj_site->GetSystemSettings();
		$this->arr_system_default = $result;
		$this->obj_tmpl->addVar('footer', 'SITE_MAIL', $this->arr_system_default['siteemail']);
		// display group aplikasi info
		$result = $this->obj_site->GetGroupAplikasiById(array($this->arr_config['app_group']['public']));
		$this->obj_tmpl->addVar('head', 'SITE_DESC', $result['meta_desc']);
		$this->obj_tmpl->addVar('head', 'SITE_KEYWORD', $result['meta_key']);
		// redirect if maintenance
		$page = $this->arr_routes['app'].'-'.$this->arr_routes['group'].'-'.$this->arr_routes['module'].'-'.$this->arr_routes['page'];
		if($this->arr_system_default['maintenance'] == '1' AND $page != 'public-home-info-underconstruction'){
			$this->obj_ctrl->RedirectPage('public', 'home', 'info', 'underconstruction');
		}
	}
	// title
	protected function DisplayWebTitle(){
		// display web title
		$str_web_page = $this->obj_nav->GetPageTitle($this->arr_routes);
		if(!empty($str_web_page)){
			$this->obj_tmpl->addVar('head', 'SITE_TITLE', $str_web_page['group_title']);
			$this->obj_tmpl->addVar('head', 'PAGE_TITLE', $str_web_page['page_title']);
		}else{
			$this->obj_tmpl->addVar('head', 'SITE_TITLE', 'IKATAN FISIOTERAPI INDONESIA');
			$this->obj_tmpl->addVar('head', 'PAGE_TITLE', 'Home');
		}
	}
	
	// navigation
	private function DisplayTopNavigation(){
		$params = array($this->arr_config['app_group']['public'], 0);
		$rs_id = $this->obj_nav->GetNavigationByParentId($params);
		if($rs_id){
			while($rec = mysqli_fetch_assoc($rs_id)){
				$url = $this->obj_ctrl->GetUrl($rec['app'], $rec['group'], $rec['module'], $rec['page']);
				$this->obj_tmpl->addVar('list_navigation', 'JUDUL', $rec['title']);
				$this->obj_tmpl->addVar('list_navigation', 'URL', $url);
				$this->obj_tmpl->addVar('list_navigation', 'CHILD_NAVIGATION', self::GetChildNavigation($rec['id_nav']));
				$this->obj_tmpl->ParseTemplate('list_navigation', 'a');	
			}
		}
	}
	
	private function GetChildNavigation($parent){
		$str_result = "";
		$params = array($this->arr_config['app_group']['public'], $parent);
		$rs_id = $this->obj_nav->GetNavigationByParentId($params);
		$num_rows = mysqli_num_rows($rs_id);
		if(!empty($num_rows)){
			$str_result = "<ul>";
			while($rec = mysqli_fetch_assoc($rs_id)){
				$url = $this->obj_ctrl->GetUrl($rec['app'], $rec['group'], $rec['module'], $rec['page']);
				$str_result .= "<li>";
				$str_result .= "<a href=\"$url\">".$rec['title']."</a>";
				$str_result .= "</li>";
			}
			$str_result .= "</ul>";		
		}
		return $str_result;
	}
	
	// login	
	private function DisplayErrorLogin(){
		if(isset($this->arr_routes['params'][0]) AND $this->arr_routes['params'][0] == 'error'){
			$this->obj_tmpl->addVar('login', 'display', 'error');
		}elseif(isset($_SESSION['user_login']) AND $_SESSION['user_login'] == true){
			// link to operator main feature
			$this->obj_tmpl->addVar('login', 'URL_MENU', $this->obj_ctrl->GetUrl('private', 'private', 'info', 'terbaru'));
			$this->obj_tmpl->addVar('login', 'display', 'still_login');
		}
	}
	// ------------------------
	
	// event
	private function DisplayListEvents(){
		$events = $this->obj_event->GetAgenda(array(0, 5));
		foreach($events as $key => $value) {
			$this->obj_tmpl->addVar('list_event', 'EVENT_TITLE', $value['judul']);
			$this->obj_tmpl->addVar('list_event', 'EVENT_START', $this->obj_date->GetFullDate($value['tgl_mulai']));
			$this->obj_tmpl->addVar('list_event', 'EVENT_HREF', $this->obj_ctrl->GetURL($this->arr_routes['app'], 'information', 'events', 'detail', array($value['id_agenda'])));
			$this->obj_tmpl->ParseTemplate('list_event', 'a');
		}
		$href = $this->obj_ctrl->GetUrl($this->arr_routes['app'], 'information', 'events', 'archive');
		$this->obj_tmpl->addVar('sidebar', 'EVENT_ALL', $href);
	}

	// announcement
	private function DisplayListAnnouncements(){
		// parsing data
		$rs_id = $this->obj_mailbox->GetResourceId("GetListAnnouncementByTipe", array('public', 0, 3));	
		if($rs_id){
			while($rs = mysqli_fetch_assoc($rs_id)){	
				// parse data
				$this->obj_tmpl->addVar('list_announce', 'SENDER', $rs['nama_lengkap']);
				$this->obj_tmpl->addVar('list_announce', 'TITLE', $rs['title']);
				$this->obj_tmpl->addVar('list_announce', 'POST_DATE', $this->obj_date->GetFullDate($rs['mdd'], 'ins'));
				$this->obj_tmpl->addVar('list_announce', 'URL_VIEW', $this->obj_ctrl->GetURL($this->arr_routes['app'], 'information', 'announce', 'detail', array($rs['id'])));
				$this->obj_tmpl->ParseTemplate('list_announce', 'a');
			}
		}
	}
	
	// get counter
	private function DisplayCounter(){
		
		if (!isset($_SESSION['counter'])){
			$_SESSION['counter']=true;
			$ip_client=$_SERVER['REMOTE_ADDR'];
			$this->obj_site->ProcessingData("Sidebar_SetCounter",array($ip_client));
			
		}
		
		$result = $this->obj_site->GetDatasetAsArray("Sidebar_GetCounter",array());
		$total='';
		if(!empty($result)){
			$this->obj_tmpl->addVar('sidebar', 'TODAY',$result[0]["today"]);
			$this->obj_tmpl->addVar('sidebar', 'YESTERDAY',  $result[0]["yesterday"] );
			$this->obj_tmpl->addVar('sidebar', 'WEEK', $result[0]["this_week"] );
			$this->obj_tmpl->addVar('sidebar', 'MONTH', $result[0]["this_month"] );
			$this->obj_tmpl->addVar('sidebar', 'ALL',  $result[0]["all_visitor"] );	
		 	$total=sprintf("%06s",$result[0]["all_visitor"]);
		}
		$counter='';
		for($i=0;$i<strlen($total);$i++){
			$char=substr($total,$i,1);
			$counter.='<img src="'.HTTPPATH.'/application/themes/default/img/counter/'. $char.'.gif" alt="'.$char.'"/>';
		}
		$this->obj_tmpl->addVar('sidebar', "COUNTER_PIC",$counter);
	}
}
?>